#!/bin/ksh
#> This script will install Prospect 8.0 / Nortel MTX18 RP16.7 HF02  (18.0.16.7.2.1)

#> Usage: install.sh {-help|-install|-uninstall}
#

InstallFileset='
vendor/Nortel/MSC/1.3/NBSS/config/colDefsNBSS14/colDef_RADIOSECTOR
vendor/Nortel/MSC/1.3/NBSS/config/colDefsNBSS15/colDef_RADIOSECTOR
vendor/Nortel/MSC/1.3/NBSS/config/colDefsNBSS16/colDef_RADIOSECTOR
vendor/Nortel/MSC/1.3/NBSS/config/colDefsNBSS17/colDef_RADIOSECTOR
vendor/Nortel/MSC/1.3/NBSS/config/colDefsNBSS18/colDef_RADIOSECTOR
vendor/Nortel/MSC/NortelMTX.build
'

########################################################
# set paths and files

RELEASE="18.0.16.7.2.1"
SourceDir="${FLEXPM_HOME}/patches/${RELEASE}"
SourceDir1="${FLEXPM_HOME}/patches/${RELEASE}/nortel"
BackupDir="${FLEXPM_HOME}/patches/${RELEASE}/backup/"

########################################################

### give help
  ToolName=`basename $0`
  runTime=`date '+%Y%m%d%H%M'`
  case $1 in
  -help|-usage)
    echo "${ToolName} usage information -- " 1>&2
    grep "^#> " $0 1>&2
    grep "^#>  \"" $0 1>&2
    exit 2
    ;;
  esac

# Check env settings

  if [ $# -ne 1 ]; then
    echo "Usage $0 {-help | -install | -uninstall}"
    exit;
  fi

  echo "Checking environment....."
  if ! [[ -d ${FLEXPM_HOME} ]]; then
    echo "Env variable FLEXPM_HOME must be set to appropriate dir before installation."
    exit;
  fi

  if [[ -z ${DB_CONNECT} ]]; then
     echo "Env variable DB_CONNECT must be set to approriate database connection values."
     exit;
  fi
 


 # Abort the patch if the server is not on RP16.7 release
  #gwdel COMP_REG=`show_installed | grep 'rev 18.0.16.7.0 b3'`
  #if [[ "$COMP_REG" == ""  ]];then
   #  echo " This server has not been upgraded to RP16.7 Nortel release. The current path required RP16.7 to be present. Aboring hotfix ..."
    # exit 1;
  #fi

  
  cd $SourceDir

# Source and destination directories

  case $1 in
  -install)
    echo "Installing patch..."
  if [[ -d ${BackupDir} ]]; then
           echo "Patch ${VERSION} may have been already applied. Aborting patch installation.\n"
           exit
  else
           mkdir -p -m 744 ${BackupDir}
  fi
    # Updating the NortelMTX.build file
    chmod +w ${FLEXPM_HOME}/vendor/Nortel/MSC/NortelMTX.build

    echo "Registration of ${RELEASE} started."
    chmod +x $FLEXPM_HOME/pm/adm/register
    register start ${SourceDir1}/vendor/Nortel/MSC/NortelMTX.build
    [[ $? -ne 0 ]] && exit 1;

    echo "Files to be updated/added ..."

    cd $SourceDir1
    touch ${BackupDir}/backup_source.tar

    for f in ${InstallFileset}
    do
        echo "${FLEXPM_HOME}/${f}"
        if [[ -a ${FLEXPM_HOME}/${f} ]]; then
        # permissions
        chmod u+w ${FLEXPM_HOME}/${f}
		
        # Keep appeding files to the backup tarball 
        tar -rf ${BackupDir}/backup_source.tar $FLEXPM_HOME/${f}

        fi
        # install files
	cp -pf ${SourceDir1}/${f} ${FLEXPM_HOME}/${f}
		
	# permissions
	#chmod u-w ${FLEXPM_HOME}/${f}
	chmod u+x ${FLEXPM_HOME}/${f}
    done

    cd $SourceDir
    echo "@upd_sourcefield.sql" | sqlplus $DB_CONNECT

    echo "+Updating NBSS loader ..."
    cd $FLEXPM_HOME/vendor/Nortel/MSC/1.3/NBSS/config
    make drop
    make global_tmp
    rm LoaderControl.txt DatabaseTable.txt DatabaseFile.txt ../data/LoaderControl.txt ../data/DatabaseTable.txt ../data/DatabaseFile.txt
    make build_loaders

    register complete ${SourceDir1}/vendor/Nortel/MSC/NortelMTX.build
     
    echo "Installation completed successfully."
    ;;

  -uninstall)

  echo ""
    echo "+ Attempting to restore backup files ..."

    cd ${FLEXPM_HOME}

    if [[ -f ${BackupDir}/backup_source.tar ]];
    then
      echo "+ Found backup files... restoring ..."
      for file in `tar -tf ${BackupDir}/backup_source.tar`
      do
         if [ -f $file ]
         then
           chmod +w $file
         fi
      done

      tar -xvf ${BackupDir}/backup_source.tar


    # Remove the component registration for this patch
      COMP_REG=`show_installed | grep 'rev 18.0.16.7.2 b1'`
      if [[ ! -z ${COMP_REG} ]]; then
sq1="select component_version_id from component_version where revision = '18.0.16.7.2' and component_id in (select component_id from component where component_name in ('NortelMTX18'))"
sq3="delete component_history where component_version_id in ( $sq1 )"
sq4="delete component_installed where component_version_id in ( $sq1 )"
sq5="delete component_version where component_version_id in ( $sq1 )"
sqlplus -s /nolog <<EOF
connect $DBUSER/$DBPASSWD@$DBSID
${sq3};
${sq4};
${sq5};
exit;
EOF

    echo "+Updating NBSS loader ..."
    cd $FLEXPM_HOME/vendor/Nortel/MSC/1.3/NBSS/config
    make drop
    make global_tmp
    rm LoaderControl.txt DatabaseTable.txt DatabaseFile.txt ../data/LoaderControl.txt ../data/DatabaseTable.txt ../data/DatabaseFile.txt
    make build_loaders
    cd $SourceDir
    echo "@upd_sourcefield_rev.sql" | sqlplus $DB_CONNECT
	
      fi
    else
      echo "+ Backup files not found... exiting..."
      exit;
    fi
    cd ${START_DIR}

  echo "End: " `date`

  echo "Un-installation Complete."
    break
    ;; 

  * )
    echo "Unknown option"
    echo "Usage: install.sh {-help|-install|-uninstall}"
    ;;
  esac
